Handbook - Reproductive System Part VI Egg-laying Apparatus
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

REPRODUCTIVE SYSTEM EGG-LAYING APPARATUS Click pictures for new window with figure and legend, click again for high resolution image
1 General Description The egg-laying apparatus consists of the uterus, the uterine muscles, the vulva, the vulval muscles, and a local neuropil formed by the egg-laying neurons (EggFIG 1). After fertilization, embryos pass from the spermatheca to the uterus, an epithelial egg chamber that links the two arms of the gonad. There, eggs develop to the approximately 30-cell stage (roughly 2.5 hr post-fertilization at 20°C) before being expelled into the environment via the vulva, a passageway from the uterus to the ventral exterior. Under optimal conditions, an adult hermaphrodite will lay 4-10 eggs/hour. Egg-laying is facilitated by contraction of the sex muscles: the vulval muscles, which attach to the lips of the vulva, and the uterine muscles, which encircle the uterus. Muscle activity is regulated by motor neurons, in particular motor neurons VCn (VC1-6) and HSNL/R, which synapse onto each other and onto vulval muscle arms, forming a neuropil near the vulva. Tissues comprising the egg-laying apparatus arise from several different lineages (see ReproTABLE 1). As described below, the developing gonad and vulva act as organizing centers, recruiting cells from other regions to the midbody, coordinating cell patterning between different tissues, and directing axon guidance and synaptic patterning of the neurons. EggFIG 1: DIC image of adult hermaphrodite midbody region. Lateral view, left side. Tissues that contribute to the egg-laying apparatus are highlighted by the color overlay. (DG) Distal gonad; (PG) proximal gonad; VC1-6 and HSNL are motor neurons that control egg-laying. VC1 (not shown) is located more anteriorly, outside the field of view. Magnification, 400x.
2 The Uterus The uterus consists of an anterior and posterior lobe joined to a central chamber. The central chamber is joined ventrally to the vulval epithelial tube (EggFIG 2A,B and EggFIG 3A). The entire outer (basal) surface of the uterus is covered by a thin basal lamina called the uterine basal lamina (UBL) (EggFIG 3B; see also EggFIG 11C). The organization of cells that comprise the uterus is most readily apparent during the late-L4 stage, after uterine and vulval morphogenesis have taken place but before the onset of ovulation, after which the uterus becomes distorted and crowded with embryos. The anterior and posterior uterus lobes are each composed of four uterine toroid epithelial syncytia: ut1, ut2, ut3 and ut4 (EggFIG 2A,B; EggTABLE 1). ut1–ut4 are joined to one another and to their neighbors both by adherens junctions (EggFIG 2C) and by pleated septate junctions, most robust between ut4 and ut3 and less obvious at the other borders. Cytoskeletal elements are sometimes evident in ut toroids, running circumferentially, suggesting that the toroids may have myoepithelial properties (Newman et al., 1996). EggFIG 2A-D: Uterus structure. A&B. Schematics of the uterus at late L4, after completion of uterus morphogenesis but before the first ovulation. A. Lateral view. The right side of A is a cutaway view. B. Ventral view. (Based on Newman et al., 1996.) C. Epifluorescent image, lateral view, left side, of an adult ajm-1::GFP transgenic hermaphrodite, midbody region. (Strain source: J. Simske.) (aj) Adherens junction. Magnification, 400x. D. Epifluroescent image, lateral view of an adult ajm-1::GFP transgenic hermaphrodite showing the adherens junctions at cell borders, midbody region. EggFIG 2E-G: Uterus structure. E. Nomarski image of uterus and vulva, lateral view, with overlay of GFP from panel F. F. Epifluorescent image, lateral view, left side, of an adult F20DF12.5::GFP transgenic hermaphrodite, midbody region. G. Epifluorescent image, lateral view of an adult C30F12.1::GFP transgenic hermaphrodite. EggFIG 3: Electron micrographs of the uterus. TEMs of the L4 uterus, after completion of uterus morphogenesis, but before the first ovulation. A. Transverse section of a late-L4 hermaphrodite from the region shown in EggFIG 2A and EggFIG 3C. (Image source: L4Vul [MRC] 4868-20.) B. A closer view of A in the region where the uterus and vulva join the body wall at the lateral seam. (UBL) Uterine basal lamina. (Image source: L4Vul [MRC] 4869-4.) C. Graphic rendition of the uterus, transverse view. (BWM) Body wall muscle; (aj) adherens junction. (Adapted from Neuman et al., 1996.) EggTABLE 1: Cells of the adult uterus. aAdult uterus cells: (ut) uterine toroid; (utse) uterine seam; (uv) uterine ventral; (du) dorsal uterine. bSPh precursor: (SPh) Somatic gonadal primordium of the hermaphrodite (see EggFIG 14A and SomaticFIG 1); (VU) ventral uterine precursor; (DU) dorsal uterine precursor; (AC) anchor cell. Note: The AC is not a precursor cell; it fuses with the utse, which is formed by fusion of eight VU grand progeny. *The neurosecretory uv1 cells are the likely source of the tyramine that controls egg laying. The close proximity of the uv1 cells to the egg-laying neuromusculature suggests a paracrine role for tyramine in the inhibition of egg laying. The uv1 cells form adherens junctions with the utse and the vulF vulval cells, and help connect the uterus with the vulva. They contain neurosecretory vesicles and express several neurosecretory proteins, including SNT-1 (synaptotagmin), UNC-64 (syntaxin), IDA-1 (phogrin-IA-2) as well as neuropeptides (Alkema et al., 2005 and the references therein). The central chamber of the uterus is capped dorsally by the dorsal uterine (du) syncytium and ventrally by the uterine seam (utse) syncytium and uterine ventral (uv) cells uv1–3 (EggFIG 2A,B and EggFIG 3A,B; EggTABLE 1). uv1–uv3 form a multilayered set of flaps, binding the ventral uterus to the dorsalmost ring of the vulva, vulF. The utse has a distinctive H-shaped structure. The two sides of the H attach to the lateral seam of the animal and hold the uterus in place. At the join, the basal lamina is thickened and contains hemicentin (EggFIG 3B) (Vogel and Hedgecock, 2001). The central portion of the utse (the crossbar of the H) initially forms a hymen membrane between uterine and vulval lumens. Passage of the first egg breaks this membrane and the two lumens become continuous. Before the first fertilization event, the lumen of the uterus is narrow and blocked by a series of inwardly projecting fingers that extend from the uterine lumen wall (see EggFIG 5B and EggFIG 11B below). After passage of the first egg, the mature uterus retains a few inward septa that may derive from these earlier fingers. Both the developing and the mature uterine lumen have a continuous thickening or electron-dense layer (possibly a glycocalyx or surface coat; see EggFIG 11C). This is also apparent on the lumenal (apical) membrane, lining projecting fingers, and septa. Cells of the uterus arise from dorsal uterine (DU) and ventral uterine (VU) blast cells of the larval SPh (Reproductive System - Somatic Gonad; EggFIG 4A; EggTABLE 1) (Kimble and Hirsh, 1979; Newman et al., 1996). In late L2, one of two somatic gonadal cells, Z1ppp or Z4aaa, is specified to become the anchor cell (AC), whereas the other becomes one of three VU blast cells (EggFIG 4A) (Kimble, 1981; Greenwald et al., 1983; Seydoux and Greenwald, 1989; Greenwald, 1997; Karp and Greenwald, 2003). EggFIG 4A&B: Uterus development. A. Lateral view. Reciprocal signaling between VU cells Z1ppp (AC/VU) and Z4aaa (AC/VU) establishes one as the anchor cell (AC) and the other as a ventral uterine (VU) precursor cell. (DU) Dorsal uterine precursor; (SPh) somatic gonadal primordium of the hermaphrodite. Precursors are colored according to the tissues to which they give rise in the adult. B. Lateral view. LIN-12 signal from the AC induces the six nearest VU grand progeny to adopt the π fate. Remaining VU grand progeny adopt the ρ fate. EggFIG 4C&D: Uterus development. C. Ventral view. Arrangement of π daughters in the developing ventral uterus. D. Ventral view. The utse cell is generated by fusion of eight π daughters. The AC is positioned ventrally to the uterus and dorsally to the vulva (not shown) and fuses with utse. (See Complete Z lineages.) (Based on Newman and Sternberg, 1996; Greenwald, 1997.) In late L3, the AC induces VU granddaughters to adopt the π fate (EggFIG 4B and EggFIG 5A). π daughters subsequently differentiate into uv1 and utse cells of the ventral uterus, which lie immediately dorsal of the developing vulva (EggFIG 4C,D and EggFIG 5B,C) (Newman et al., 1995, 1996; Chang et al., 1999). The differentiation of these and many other terminal uterine cells involves dramatic changes in shape and/or fusion to achieve their final morphology (Newman et al., 1996). As described below, the AC also patterns cells of the vulva. This dual induction of vulval and uterine cell fates by the AC ensures that cells forming the physical connection between the uterus and vulva (utse, uv1, and vulF) develop in physical register. The AC also contributes to formation of this connection by creating an opening at the apex of the vulva. EggFIG 5A&B: Cell fate patterning during uterus development. A. DIC/epifluorescent image, lateral view, left side, of an early-L4 transgenic animal expressing an egl-13/cog-2::GFP reporter gene in the π cells. (Strain source: W. Hanna-Rose.) Magnification, 1000x. B. DIC, lateral view, left side, of an early-L4 transgenic animal expressing a cog-1::GFP reporter gene. (Strain source: R.E. Palmer and P.W. Sternberg.) EggFIG 5C&D: Cell fate patterning during uterus development. C. DIC/epifluroescent image, laterl view, left side of a mid-L4 animal. D. DIC/epifluorescent image, ventral view, of an adult ida-1::GFP transgenic animal showing reporter expression in the four uv1 cells of the ventral uterus. Magnification, 1000x. (Strain source: T. Zahn and J. Hutton.)
3 The Vulva The vulva (EggFIG 6A) is formed from a stack of seven nonequivalent epithelial toroids or rings: (in ventral-to-dorsal order) vulA, vulB1, vulB2, vulC, vulD, vulE, and vulF (EggFIG 3A). Each ring is either a single tetranucleate syncytium or two binucleate half-ring syncytia (vulB1 and vulB2). The vulval lumen is lined with cuticle. As described below, the toroids are formed by vulval cells of two fates: primary fate (vulE and vulF) or secondary fate (vulA–D). These cells and the toroids they form express distinct combinations of genes (Inoue et al., 2002) and, potentially, different characteristics and properties. For example, during copulation, males locate the vulva with their hook and post-cloacal sensilla, possibly in response to signals or characteristics associated specifically with toroids formed by secondary-fated cells (M. Barr, pers. comm.). EggFIG 6A&B: The adult vulva. A. SEM, ventral view. (Image source: N8 [Hall] Vulva.) B. DIC/epifluorescent image, ventral view, of a young adult transgenic animal expressing an ajm-1::GFP reporter gene. The fusion protein localizes to the apical (lumenal) surface of each vulval toroid. Magnification, 1000x. (Strain source: H. Yu and P.W. Sternberg.) EggFIG 6C-E: The adult vulva. C. DIC/epifluorescent image, ventral view, of a young adult transgenic animal expressing an ajm-1::GFP reporter gene. The fusion protein localizes to the apical (lumenal) surface of each vulval toroid. Magnification, 1000x. (Strain source: H. Yu and P.W. Sternberg. D. TEM, horizontal section of an adult vulva featuring the cuticle, lumen and surrounding vulval toroids and the borders between them. (Image source: N507 [Hall] V971.) E. TEM, horizontal section, in the region indicated by the box in 6D, showing adherens junctions between vulval toroid borders. (Image source: N507 L5 [Hall] V778.) Adjacent toroids are joined to their neighbors via adherens junctions (EggFIG 6E). The dorsalmost toroid vulF is also linked by adherens junctions to the uterine transitional epithelial cells uv1 and uv2 and possibly to the utse (EggFIG 3A). The ventralmost toroid vulA is linked via adherens junctions to the ventral hypodermal ridge. The vulE toroid stretches laterally and is linked on its basal (outer) surface to the body wall at the lateral seam by a specialized thickened basal lamina (EggFIG 3A,B). Vulval development spans roughly the same period as uterine development: L3 to late L4. For a summary figure of the stages of vulval development, please see EggFIG Sup1. Establishment of the vulva requires the local deformation of existing ventral structures such as the ventral nerve cord (VNC) (EggFIG 1) and ventral body wall muscles (EggFIG 3A), which are deflected laterally in this region to accommodate the vulva. Vulval development can be divided into two phases: (1) vulval cell patterning and generation (EggFIG 7 and EggFIG 8) and (2) vulval morphogenesis (EggFIG 9). The molecular and genetic mechanisms underlying these processes, particularly cell patterning, have been studied extensively and are described in the following reviews and papers and references therein (Greenwald, 1997; Kim, 1997; Eisenmann et al., 1998; Levitan and Greenwald, 1998; Hanna-Rose and Han, 2000; Shemer and Podbilewicz, 2003; Ceol and Horvitz, 2004; Sundaram, 2004). EggFIG 7: Vulval cell patterning. A. Establishment of vulval precursor cell (VPC) fates. Schematic, lateral view, showing the three known signaling events that establish primary, secondary, and tertiary vulval precursor fate among the midbody Pnp cells during early L3. (Based on Greenwald, 1997; Sundaram, 2004.) B. Lineal origin of terminal vulval cells. Top Lineages of the VPCs. VPC primary, secondary, or tertiary fate is defined by the lineage pattern expressed by a given VPC. The plane of cell division is relative to the animal body axis. (T) Left/right; (L) anteroposterior; (N) no division; (S) fusion with hypodermal syncytium. The scale on the left indicates the larval stage of development and time post-hatching in hours (hr) at 20°C. The corresponding number of VPC progeny cells present at each step of the lineage is shown on the right. Bottom Arrangement of terminal vulval cells after completion of the lineage, dorsal view. A-F correspond to the adult vulval toroids (vuls) formed by the fusion of specific groups of terminal cells (depicted in EggFIG9). (Based on Sulston and Horvitz, 1977; Sternberg and Horvitz, 1986; Sharma-Kishore et al., 1999.) EggFIG 8: Interactions between the AC and cells of the developing vulva. DIC/ epifluorescent images, lateral view, left side, of cdh-3::GFP transgenic animals at various stages of the vulval cell lineage. The reporter gene is expressed in the anchor cell (AC; arrowhead) at all stages shown. A. Pnp stage. Earlymid L3. B. Pnpx (two-cell) stage. Mid L3. C. Pnpxx (four-cell) stage. Mid-late L3. D. Pnpxx/Pnpxxx (six- to eight-cell) stage. L3/L4 molt. Magnification, 1000x. (Strain source: D. Sherwood and P.W. Sternberg.) (Based on Sherwood and Sternberg, 2003.) EggFIG 9: Vulval morphogenesis. Dorsal view. The scale on the left indicates the larval stage of development and time post-hatching in hours (hr) at 20°C. (Based on Sharma-Kishore et al., 1999.)
3.1 Vulval Cell Patterning The cells that form the vulval toroids are the progeny of ventral hypodermal Pnp cells (EggFIG 7B) (Sulston and Horvitz, 1977). Twelve Pnp cells are born mid-L1. The six central cells P3p–P8p are endowed with equal potential to produce vulval cell lineages and are referred to as vulval precursor cells (VPCs) (EggFIG7A and EggFIG 8A). In L3, the VPCs are patterned so that vulval potential is restricted to the central three cells P5p–P7p. This patterning of the VPCs involves the combined action of three intercellular signaling events: an inductive signal emanating from the AC (LIN-3/LET-23 MAPK pathway activation), lateral signaling between VPCs (LIN-12/Notch), and signals from hyp 7 (reviewed in Greenwald, 1997; Sundaram, 2004; Sternberg, 2005). As a consequence of patterning, P6p expresses a primary vulval cell fate and P5p and P7p secondary vulval fates. The remaining VPCs express a non-vulval tertiary fate, and their progeny fuse with the hypodermis (see Epithelial System - Hypodermis; Sternberg and Horvitz, 1986). Primary, secondary, and tertiary fates are recognized by the lineage pattern generated by a given VPC (EggFIG 7B and EggFIG 8A–D). 3.2 Vulval Morphogenesis During the final round of vulval cell divisions, the primary descendants and some secondary descendants detach from the cuticle, allowing the vulval sheet to bend inward and the cells within it to rearrange their cell–cell contacts (EggFIG 8D). This invagination step establishes the beginnings of the vulval lumen, which continues to expand during morphogenesis. Proteoglycans and their associated glycosaminoglycans, likely expressed in vulval cells, are necessary for this step, although their precise role is not known (Herman and Horvitz, 1999; Bulik et al., 2000; Hwang et al., 2003). As morphogenesis continues, cells migrate toward the center of the developing vulval primordium and wrap around to meet their anterior/posterior homologs on the other side (EggFIG 9) (Sharma-Kishore et al., 1999). Homotypic cell fusions occur between cells of homologous fate, resulting in the formation of toroid or half-toroid rings (see Inoue et al., 2002 for a useful guide to vulval cell nuclei positions during and after morphogenesis). As part of the process of joining vulval and uterine lumens, the AC creates a hole in the apex of the developing vulva (EggFIG 8). In L3, while Pnp cells are dividing, the ventral hypodermal basal lamina and gonadal basal lamina break down precisely at the site of contact with the AC. The basolateral portion of the AC crosses through this gap, attaches to, then inserts between the descendants of the primary-fated P6p lineage cells. This invasion is stimulated by a diffusible signal from the primary cells (Sherwood and Sternberg, 2003). Later, P6p terminal progeny fuse, forming a toroid (vulF) around the invading AC process. The AC is then removed by heterotypic fusion with the utse, leaving a channel in the apex of the vulva (Newman et al., 1996). When the utse membrane is ruptured by passage of the first egg, uterine and vulval lumens become continuous. During late L4, the vulval muscles attach to the vulval epithelial tube and to the body wall (see below). The tube then partially everts (turns inside out), generating the adult vulva in which the lumen is closed until vulval muscles contract (EggFIG 10) (Sulston and Horvitz, 1977; Sharma-Kishore et al., 1999). EggFIG 10: Vulval morphology before and after eversion. A. DIC image of a mid- to late-L4 animal, before eversion, lateral view, midsublateral plane. B. DIC image of a mid L4 animal, before eversion, ventral surface view, showing the vulval opening along the ventral midline. C. DIC/epifluorescent image of a lin-11::GFP transgenic late-L4 animal, post-eversion, lateral view, midsublateral plane. (Strain source: B.P. Gupta and P.W. Sternberg.) D. DIC image of a young adult animal, post-eversion, ventral surface view, showing the vulval slit. EggFIG Sup1: Stages of vulval development. Time course montage showing the process of vulval development from L3/L4 through early adult stages. 4 Uterine and Vulval Muscles The uterine (um1L/R, um2L/R) and vulval (vm1L/R, vm2L/R) muscles (EggFIG 1 and EggFIG 11A), collectively referred to as the sex muscles, are required for moving eggs through the uterus and vulva. Only 4 the 16 sex muscles receive direct inputs from the egg-laying neurons. The remaining sex muscles are electrically coupled, either directly or indirectly, to these innervated muscles (see EggFIG 13). This configuration may serve to coordinate uterine and vulval contraction. The sex muscles are classified as nonstriated muscles because they do not have the striated appearance (typified by body wall muscle) normally attributed to the presence of an ordered array of multiple sarcomeres (muscle contractile units; see Muscle System - Somatic Muscle). Vulval muscles have a single sarcomere that extends along the entire muscle length and attaches to a discrete zone in the body wall at one end and to the vulva at the other end (White, 1988). The uterine muscle myofilament network seems to be anchored to a thin basal lamina on the surface facing the uterus. In contrast to the vulval muscles, the attachment points are randomly arrayed and this distribution of dense bodies is similar to that seen in vertebrate smooth muscles (see Muscle System - Nonstriated). EggFIG 11A: The uterine muscles. Epifluorescent image of an adult hlh-1/hlh2::GFP transgenic animal, midbody, lateral view, left side. This reporter is expressed in the sex muscles of the egg-laying apparatus: the uterine muscles (um1L/R and um2L/R) and the vulval muscles (vm1L/R and vm2L/R). Right-side uterine and vulval muscles (not shown) um1R, um2R, vm1R, and vm2R are located at the back. (Colored lines) Approximate boundaries of neighboring tissue. (BWM) Dorsal boundary of the ventral body wall muscle quadrant. Magnification, 1000x. (Strain source: B.D. Harfe, M. Krause, and A. Fire.) EggFIG 11B&C: The uterine muscles. B. TEM, transverse section, of a late-L4 hermaphrodite uterus (before ovulation) in the region indicated by the box in A. (um) Uterine muscle; (vm) vulval muscle; (VNCL, VNCR) ventral nerve cord, left and right fascicle, respectively. (Image source: L4 Vul [MRC] 486619.) C. TEM, transverse section of an adult hermaphrodite uterus wall at high magnification. (BL) Basal lamina; (UBL) uterine basal lamina. (Image source: N2U [MRC] A629-24.) Eight uterine muscles are arranged in four bands around the uterus lobes: two bands per lobe, two muscle cells per band (EggFIG 1). A left/right pair of um2-type muscles (um2L/R) encircles the more distal ut toroids of each lobe. A left/right pair of um1-type muscles (um1L/R) cup the ventral half of the uterus over the more proximal ut toroids, and at their dorsal edges, they attach to the lateral seam. The ventral-proximal edges of the um2 muscles overlap with the um1 muscles (EggFIG 1). Uterine muscles are covered in a thin basal lamina (EggFIG 11C). The muscle filaments are circumferentially oriented so their contraction potentially moves eggs by squeezing on the uterus (EggFIG 11C) (Sulston and Horvitz, 1977). The uterine muscles are not directly innervated and are instead coupled via gap junctions, either directly or indirectly, to vulval muscles that are innervated by the egg-laying neurons (see EggFIG 13) (White et al., 1986) (see also Gap Junctions). Eight vulval muscles are organized around the vulva into two layers of four cells: One layer contains four vm1-type muscles and the other four contain vm2-type muscles. The muscles run at diagonal angles from the vulval lips to the subventral body wall (EggFIG 12A). Their proximal ends are linked to the vulval cuticle (for details, see Muscle System - Nonstriated). EggFIG 12: The vulval muscles. A. DIC/epifluorescent image of an adult egl-15::GFP transgenic animal showing reporter expression in the eight vulval muscles, ventral view. Magnification, 1000x. (Strain source: C. Branda and M. Stern.) B. TEM, transverse section, of a late-L4 larva from the region indicated by the line in A. The image shows the ends of vulval muscles that interdigitate between the vulval toroids. (VNCL, VNCR) Ventral nerve cord, left and right fascicle, respectively; (BWM) body wall muscle. (Image source: L4 Vul [MRC] 4866-19.) EggFIG 13: Connectivity of the vulval and uterine muscles. (um) Uterine muscle; (vm) vulval muscle; VC1-6, HSN, VA7, VB6, and VD7 are motor neurons. (Adapted, with permission, from White et al., 1986.) The vm2 muscles attach between the uterus and vulF (EggFIG 12B). Their distal ends insinuate between adjacent members of the ventral body wall muscle quadrant (EggFIG 11B). vm1 muscles attach to the vulva more ventrally than do the vm2s, between vulC and vulD toroids (EggFIG 12B), but they join the body wall more dorsally, attaching near the dorsal edge of the ventral body wall muscle quadrant (EggFIG 11B). The vm2s are the only sex muscles that are directly innervated (EggFIG 13) (White et al., 1986). The muscles extend arms into the regions of neuropil formed at the vulva where they receive synaptic inputs (see EggFIG 15A, B&C). vm1 connects to vm2 by gap junctions. Coordinated foreshortening of the vulval muscles pulls the lips apart, allowing eggs to pass through the lumen and out into the environment. Uterine and vulval muscles derive from a common precursor, the sex myoblast (SM). During L1, the mesoderm (M) blast cell (EggFIG 14A,B) lineage produces a left and a right SM (SML/R) (Sulston and Horvitz, 1977). In L2, SML/R migrate anteriorly along ventral muscle quadrants to the precise center of the developing gonad and future vulva (EggFIG14C). There, the SMs undergo three rounds of division to produce the vulval and uterine muscle cells (EggFIG 14D) which then attach to the everted vulva (EggFIG 14E) (for details on muscle specification programs, see Harfe et al., 1998; Corsi et al., 2000; Lui and Fire, 2000; Kosta and Fire, 2001; Eimer et al., 2002). EggFIG 14A: Sex muscle development. Schematic showing the temporal order of events leading to establishment of the adult egg-laying system, lateral view, left side. The scale on the left indicates larval stage and corresponding hours (hr) post-hatching at 20°C. Figures showing DIC/epifluorescent images of corresponding stages are indicated in parentheses on the right. For cells of the M/SM and Pnp lineages, cell nuclei only are shown. (GP) Gonadal primordium; (VPCs) vulval precursor cells. *M is located on right side of the animal. **Of the egg-laying neurons (VC1-6 and HSNL/R), only HSNL/R axons extend into the nerve ring in the adult. (Based on Sulston and Horvitz, 1977; Li and Chalfie, 1990; Garriga et al., 1993.) (Strain source: B.D. Harfe, M. Krause and A. Fire.) EggFIG 14B-E: Sex muscle development. DIC/epifluorescent (B,D, E) or epifluorescent only (C) images of hlh-8::GFP transgenic animals, lateral view, left side, at different stages of sex muscle development. B. L1. C. Mid-L2. D. Early L4. E. Late L4. (Colored dotted lines) Relative positions of the gonadal primordium or the developing vulva. Magnification, 1000x. (Strain source: B.D. Harfe, M. Krause and A. Fire.) EggFIG 15A: Egg-laying neurons. Epifluorescent image of an adult transgenic hermaphrodite expressing an ida1::GFP reporter gene in the egg-laying neurons VC1-6 and HSNL/R, ventral view. A few other neurons (not labeled) that have processes in the ventral nerve cord (VNC) also express this marker. Magnification, 400x. (Strain source: T. Zahn and J. Hutton.) EggFIG 15B&C: Egg-laying neurons. B. Epifluorescent image of an ida1::GFP transgenic adult in the region indicated by the box in EggFIG 15A. Magnification, 1000x. (Strain source: T. Zahn and J. Hutton.) C. DIC/epifluorescent image, ventral view, left side, of an adult transgenic animal expressing a VC::GFP reporter gene. (Strain source: I.A. Bany and M. Koelle.) SM migration and positioning at the gonad center is guided by the balance of several forces: a gonad-dependent attractive (GDA) mechanism (Thomas et al., 1990), a gonad-dependent repulsive (GDR) mechanism (Stern and Horvitz, 1991), and a gonad-independent attractive (GIA) mechanism (Chen et al., 1997; Huang et al., 2003). The DUs, VUs, and AC of the SPh (EggFIG 14A) and primary-fated P6p vulval cells (EggFIG 7A) express FGF-related ligand EGL-17, which is likely to correspond to the GDA signal for SM migration. Interestingly, these same cells also appear to be the source of the GDR mechanism (Burdine et al., 1997, 1998; Branda and Stern, 2000). 5 Egg-laying Neurons The vm2 muscles receive major inputs from two groups of motor neurons, the VCn neurons (VC1–6) and the HSNs (HSNL/R) (EggFIG 15A) (see White et al., 1986 and Neuron system for detailed descriptions of each neuron). The precise role of each neuron and the neurotransmitters they release in egg-laying appears to be complex; several models have been proposed (Weinschenker et al., 1995; Waggoner et al., 1998, 2000; Bany et al., 2003; Shyn et al., 2003). VC4 and VC5 cell bodies flank the vulval epithelial tube and have short processes in the VNC. VC1, VC2, VC3, and VC6 neuron cell bodies are spaced along the length of the VNC. Each sends out a single main axon that runs in the dorsal “neighborhood” of the cord and makes similar synaptic contacts to one another. When VCn neuron axons reach the vicinity of the vulva, they send processes dorsally along the ventral basal (outer) surface of vulE (EggFIG 16). The neurons branch and synapse with one another and with the HSNs and vm2 muscle arms, forming a local neuropil (EggFIG 15B). VC4 and VC5 branch more extensively than other VC neurons in this region. EggFIG 16A: Egg-laying neurons. Schematic of the adult hermaphrodite midbody region, dorsal view, showing the vulva, vulval muscles (vm), and egg-laying neurons (VC1 and VC2 cell bodies not shown). (BWM) Body wall muscle; (VNCL, VNCR) ventral nerve cord, left and right fascicle, respectively. EggFIG 16B&C: Egg-laying neurons. TEMs, transverse sections, of an adult hermaphrodite at the axial positions indicated by the lines in A. (B Image source: N2U VC [MRC] 2178-24; C image source: N2U VC [MRC] 2179-22.) The VCn neurons are derived from the anterior daughters of ventral hypodermal blast cells P3–P8, the same cells that produce VPCs (described above; see Sulston and Horvitz, 1977). The VCn neurons are born in L1, begin to send out processes in late L3, and branch in the region of the vulva during L4 (EggFIG 14A). Surprisingly, VCn branching depends on cells of the vulva and not on the presence of their targets (Li and Chalfie, 1990; Colavita and Tessier-Lavigne, 2003). HSNL/R cell bodies are situated subventrally, just posterior to the vulva (EggFIG 15B). Each HSN axon projects ventrally to the midline to join the ipsilateral VNC (VNCR or VNCL) and from there extends into the nerve ring. As they pass the vulva, the HSNs defasciculate dorsally, branch, and form synapses with VCn neurons and vm2 muscle arms, thereby contributing to the neuropil. HSNL/R are born in the tail of the embryo and migrate before hatching to the midbody, near the gonadal primordium (EggFIG 14A) (Sulston and Horvitz, 1977; Sulston et al., 1983; Desai et al., 1988). Axon outgrowth begins during L2 and L3 and is guided by primary-fated P6p lineage cells (described above) and VNC neurons (Thomas et al., 1990; Garriga et al., 1993). Synapse formation takes place in the L3 and L4 stages. Primary vulval cells (from which vulE is formed) produce a signal that acts as a synaptic guidepost, promoting the correct pattern of presynaptic vesicle clustering in the HSNs (Shen and Bargmann, 2003; Shen et al., 2004). 6 List of Cells in the Uterus and Vulva 1. Late L2/early L3 stage SPh cells that give rise to the uterus DU, Z1.pap (Dorsal Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) VUs and AC are of either the 5R or 5L configuration: 5R configuration VU, Z1.ppa (Ventral Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) AC, Z1.ppp (Anchor Cell) VU, Z4.aaa (Ventral Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) VU, Z4.aap (Ventral Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) 5L configuration VU, Z1.ppa (Ventral Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) VU, Z1.ppp (Ventral Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) AC, Z4.aaa (Anchor Cell) VU, Z4.aap (Ventral Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) DU, Z4.apa (Dorsal Uterine precursor; generates uterus, spermatheca and spermatheca-uterine valve cells) 2. L3 stage intermediate blast cells of the uterus The Dorsal Eight (DE) cells (great-grand progeny of the DUs) DE1, Z1.papaaa (generates anterior arm sp cells) DE2, Z1.papaap (generates anterior arm sp and sujc valve cells) DE3, Z1.papapa (generates anterior arm sujn valve cells and ut2-4 uterus cells) DE4, Z1.papapp (generates uv3, uv2, ut1, du) DE5, Z1.pappaa (generates du, ut1, uv2, uv3) DE6, Z1.pappap (generates ut2-4 and posterior arm sujn valve) DE7, Z1.papppa (generates posterior arm sujc valve and sp) DE8, Z1.papppp (generates posterior arm sp) DE1, Z4.apaaaa (generates anterior arm sp) DE2, Z4.apaaap (generates anterior arm sujc valve and sp) WB says male gon sv group DE3, Z4.apaapa (generates anterior arm sujn valve cells and ut2-4 uterus cells) DE4, Z4.apaapp (generates uv3, uv2, ut1, du) DE5, Z4.apapaa (generates du, ut1, uv2, uv3) DE6, Z4.apapap (generates ut2-4 and posterior arm sujn valve) DE7, Z4.apappa (generates posterior arm sujc valve and sp) DE8, Z4.apappp (generates posterior arm sp) 3. Adult uterus ut1 - anterior (5L, 5R), posterior (5L, 5R) ut2 - anterior (5L, 5R), posterior (5L, 5R) ut3 - anterior (5L, 5R), posterior (5L, 5R) ut4 - anterior (5L, 5R), posterior (5L, 5R) du utse - 5L, 5R uv1 uv2 uv3 4. L3 stage Vulva Precursor Cells (VPCs) P3.p P4.p P5.p P6.p P7.p P8.p 5. Adult vulva vulA vulB1 vulB2 vulC vulD vulE vulF 6. Uterine and vulval muscles (sex muscles) um1L/R um2L/R vm1L/R vm2L/R 7. Egg-laying neurons VCn (VC1-6) HSNL/R 7 References Alkema, M.J., Hunter-Ensor, M., Ringstad, N. and Horvitz, H.R. 2005. Tyramine functions independently of octopamine in the Caenorhabditis elegans nervous system. Neuron 46: 247-250. Article Bany, I.A., Dong, M.Q. and Koelle, M.R. 2003. Genetic and cellular basis for acetylcholine inhibition of Caenorhabditis elegans egg-laying behavior. J. Neurosci. 23: 8060-8069. Article Branda, C.S. and Stern, M.J. 2000. Mechanisms controlling sex myoblast migration in Caenorhabditis elegans hermaphrodites. Dev. Biol. 226: 137-151. Article Bulik, D.A., Wei, G., Toyoda, H., Kinoshita-Toyoda, A., Waldrip, W.R., Esko, J.D., Robbins, P.W. and Selleck, S.B. 2000. sqv-3, -7, and -8, a set of genes affecting morphogenesis in Caenorhabditis elegans, encode enzymes required for glycosaminoglycan biosynthesis. Proc. Natl. Acad. Sci. 97: 10838-10843. Article Burdine, R.D., Chen, E.B., Kwok, S.F. and Stern, M.J. 1997. egl-17 encodes an invertebrate fibroblast growth factor family member required specifically for sex myoblast migration in Caenorhabditis elegans. Proc. Natl. Acad. Sci. 94: 2433-2437. Article Burdine, R.D., Branda, C.S. and Stern, M.J. 1998. EGL-17(FGF) expression coordinates the attraction of the migrating sex myoblasts with vulval induction in C. elegans. Development 125: 1083-1093. Article Ceol, C.J. and Horvitz, H.R. 2004. A new class of C. elegans synMuv genes implicates a Tip60/NuA4-like HAT complex as a negative regulator of Ras signaling. Dev. Cell 6: 563-576. Article Chang, C., Newman, A.P. and Sternberg, P.W. 1999. Reciprocal EGF signaling back to the uterus from the induced C. elegans vulva coordinates morphogenesis of epithelia. Curr. Biol. 9: 237-246. Article Chen, E.B., Branda, C.S. and Stern, M.J. 1997. Genetic enhancers of sem-5 define components of the gonad-independent guidance mechanism controlling sex myoblast migration in Caenorhabditis elegans hermaphrodites. Dev. Biol. 182: 88-100. Article Colavita, A. and Tessier-Lavigne, M. 2003. A Neurexin-related protein, BAM-2, terminates axonal branches in C. elegans. Science 302: 293-296. Abstract Corsi, A.K., Kostas, S.A., Fire, A. and Krause, M. 2000. Caenorhabditis elegans twist plays an essential role in non-striated muscle development. Development 127: 2041-2051. Article Desai, C., Garriga, G., McIntire, S.L. and Horvitz, H.R. 1988. A genetic pathway for the development of the Caenorhabditis elegans HSN motor neurons. Nature 336: 638-646. Abstract Eimer, S., Donhauser, R. and Baumeister, R. 2002. The Caenorhabditis elegans presenilin sel-12 is required for mesodermal patterning and muscle function. Dev. Biol. 251: 178-192. Article Eisenmann, D.M., Maloof, J.N., Simske, J.S., Kenyon, C. and Kim, S.K. 1998. The beta-catenin homolog BAR-1 and LET-60 Ras coordinately regulate the Hox gene lin-39 during Caenorhabditis elegans vulval development. Development 125: 3667-3680. Article Garriga, G., Desai, C. and Horvitz, H.R. 1993. Cell interactions control the direction of outgrowth, branching and fasciculation of the HSN axons of Caenorhabditis elegans Development 117: 1071-1087. Article Greenwald, I.S., Sternberg, P.W. and Horvitz, H.R. 1983. The lin-12 locus specifies cell fates in Caenorhabditis elegans. Cell 34: 435-444. Abstract Greenwald, I. 1997. Development of the Vulva. In C. elegans II (ed. D. L. Riddle et al.). chap. 19. pp. 519-541. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Hanna-Rose, W. and Han, M. 2000. Getting signals crossed in C. elegans. Curr. Opin. Genet. Dev. 10: 523-528. Abstract Harfe, B.D., Branda, C.S., Krause, M., Stern, M.J. and Fire, A. 1998. MyoD and the specification of muscle and non-muscle fates during postembryonic development of the C. elegans mesoderm. Development 125: 2479-2488. Article Herman, T. and Horvitz, H.R. 1999. Three proteins involved in Caenorhabditis elegans vulval invagination are similar to components of a glycosylation pathway. Proc. Natl. Acad. Sci. 96: 974-979. Article Huang, X., Huang, P., Robinson, M.K., Stern, M.J. and Jin, Y. 2003. UNC-71, a disintegrin and metalloprotease (ADAM) protein, regulates motor axon guidance and sex myoblast migration in C. elegans. Development 130: 3147-3161. Article Hwang, H.Y., Olson, S.K., Esko, J.D. and Horvitz, H.R. 2003. Caenorhabditis elegans early embryogenesis and vulval morphogenesis require chondroitin biosynthesis. Nature 423: 439-443. Abstract Inoue, T., Sherwood, D.R., Aspock, G., Butler, J.A., Gupta, B.P., Kirouac, M., Wang, M., Lee, P.Y., Kramer, J.M., Hope, I., Burglin, T.R. and Sternberg, P.W. 2002. Gene expression markers for Caenorhabditis elegans vulval cells. Mech. Dev. 119 Suppl 1: S203-209. Article Karp, X. and Greenwald, I. 2003. Post-transcriptional regulation of the E/Daughterless ortholog HLH-2, negative feedback, and birth order bias during the AC/VU decision in C. elegans. Genes Dev. 17: 3100-3111. Article Kim, S.K. 1997. Polarized signaling: basolateral receptor localization in epithelial cells by PDZ-containing proteins. Curr. Opin. Cell Biol. 6: 853-9. Abstract Kimble, J. 1981. Alterations in cell lineage following laser ablation of cells in the somatic gonad of Caenorhabditis elegans. Dev. Biol. 87: 286-300. Abstract Kimble, J. and Hirsh, D. 1979. The postembryonic cell lineages of the hermaphrodite and male gonads in Caenorhabditis elegans. Dev. Biol. 70: 396-417. Article Kostas, S.A. and Fire, A. 2002. The T-box factor MLS-1 acts as a molecular switch during specification of nonstriated muscle in C. elegans. Genes Dev. 16: 257-269. Article Levitan, D. and Greenwald, I. 1998. Effects of SEL-12 presenilin on LIN-12 localization and function in Caenorhabditis elegans. Development 125: 3599-3606. Article Li, C. and Chalfie, M. 1990. Organogenesis in C. elegans: Positioning of neurons and muscles in the egg-laying system. Neuron 4: 681-695. Abstract Liu, J. and Fire, A. 2000. Overlapping roles of two Hox genes and the exd ortholog ceh-20 in diversification of the C. elegans postembryonic mesoderm. Development 127: 5179-5190. Article Newman, A.P. and Sternberg, P.W. 1996. Coordinated morphogenesis of epithelia during development of the Caenorhabditis elegans uterine-vulval connection. Proc. Natl. Acad. Sci. 93: 9329-9333. Article Newman, A.P., White J.G. and Sternberg, P.W. 1996. Morphogenesis of the C. elegans hermaphrodite uterus. Development 122: 3617-3626. Article Newman, A.P., White, J.G. and Sternberg, P.W. 1995. The Caenorhabditis elegans lin-12 gene mediates induction of ventral uterine specialization by the anchor cell. Development 121: 263-271. Article Schedl, T. 1997. Developmental Genetics of the Germ Line. In C. elegans II (ed. D. L. Riddle et al.). chap. 10. pp. 417-500. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Seydoux, G. and Greenwald, I. 1989. Cell autonomy of lin-12 function in a cell fate decision in C. elegans. Cell 57: 1237-1245. Article Sharma-Kishore, R., White, J.G, Southgate, E. and Podbilewicz, B. 1999. Formation of the vulva in Caenorhabditis elegans: a paradigm for organogenesis. Development 126: 691-699. Article Shemer, G. and Podbilewicz, B. 2003. The story of cell fusion: big lessons from little worms. Bioessays 25: 672-682. Abstract Shen, K. and Bargmann, C.I. 2003. The immunoglobulin superfamily protein SYG-1 determines the location of specific synapses in C. elegans. Cell 112: 619-630. Article Shen, K., Fetter, R.D. and Bargmann, C.I. 2004. Synaptic specificity is generated by the synaptic guidepost protein SYG-2 and its receptor, SYG-1. Cell 116: 869-881. Article Sherwood, D.R. and Sternberg, P.W. 2003. Anchor cell invasion into the vulval epithelium in C. elegans. Dev. Cell 5: 21-31. Article Shyn, S.I., Kerr, R. and Schafer, W.R. 2003. Serotonin and Go modulate functional states of neurons and muscles controlling C. elegans egg-laying behavior. Curr. Biol.13: 1910-1915. Article Stern, M.J. and Horvitz, H.R. 1991. A normally attractive cell interaction is repulsive in two C. elegans mesodermal cell migration mutants. Development 113: 797-803. Article Sternberg, P.W. and Horvitz, H.R. 1986. Pattern formation during vulval development in C. elegans. Cell 44: 761-72. Abstract Sulston, J. E. and Horvitz, H. R. 1977. Post-embryonic cell lineages of the nematode Caenorhabditis elegans. Dev. Biol. 56: 110-156. Article Sulston, J.E., Schierenberg, E., White, J.G., and Thomson, J.N. 1983.The embryonic cell lineage of the nematode Caenorhabditis elegans. Dev. Biol. 100: 64-119. Article Sundaram, M.V. 2004. Vulval development: the battle between Ras and Notch. Curr. Biol. 14: R311-313. Article Thomas, J.H., Stern, M.J. and Horvitz, H.R. 1990. Cell interactions coordinate the development of the C. elegans egg-laying system. Cell 62: 1041-1052. Abstract Vogel, B.E. and Hedgecock, E.M. 2001. Hemicentin, a conserved extracellular member of the immunoglobulin superfamily, organizes epithelial and other cell attachments into oriented line-shaped junctions. Development 128: 883-894. Article Waggoner, L.E., Zhou, G.T., Schafer, R.W. and Schafer, W.R. 1998. Control of alternative behavioral states by serotonin in Caenorhabditis elegans. Neuron 21: 203-214. Article Waggoner, L.E., Hardaker, L.A., Golik, S. and Schafer, W.R. 2000. Effect of a neuropeptide gene on behavioral states in Caenorhabditis elegans egg-laying. Genetics 154: 1181-1192. Article Weinshenker, D., Garriga, G. and Thomas, J.H. 1995. Genetic and pharmacological analysis of neurotransmitters controlling egg laying in C. elegans. J. Neurosci. 15: 6975-6985. Article White, J. 1988. The Anatomy. In The nematode C. elegans (ed. W. B. Wood). chapter 4. pp 81-122. Cold Spring Harbor Laboratory Press, New York. Abstract White J.G., Southgate, E., Thomson, J.N., and Brenner, S. 1986. The structure of the nervous system of the nematode C. elegans. Philos. Trans. R. Soc. Lond. Ser. B. Biol. Sci. 314: 1-340. Article
This chapter should be cited as: Lints, R. and Hall, D.H. 2009. Reproductive system, egglaying apparatus. In WormAtlas. doi:10.3908/wormatlas.1.24 Edited for the web by Laura A. Herndon. Last revision: February 1, 2013.

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |